capture log close
set more off
program drop _all
macro drop _all
scalar drop _all
clear all


global root "C:\iPEHD"


use $root/ipehd_qje2009_master.dta, clear


global controls "f_young f_jew f_fem f_ortsgeb f_pruss hhsize lnpop gpop f_blind f_deaf f_dumb"


* Table 1: Descriptive Statistics in 19th-Century Prussia

sum inctaxpc yteacher perc_secBnC perc_secB perc_secC f_prot f_cath f_rw f_over3km kmwittenberg 
sum f_young f_jew f_fem f_ortsgeb f_pruss hhsize pop gpop f_miss f_blind f_deaf f_dumb 
sum kmb lat_rad lon_rad poland f_mine f_urban zupreussen


* Table 2: The Association between Protestantism and Literacy in 19th-Century Prussia

reg f_rw f_prot
reg f_rw f_prot $controls f_miss 
reg f_rw f_prot $controls f_miss lnkmb lat_rad lon_rad latlon poland f_mine f_urban
xi: reg f_rw f_prot $controls f_miss lnkmb lat_rad lon_rad latlon poland f_mine f_urban i.rbkey
reg f_rw f_prot $controls f_miss zupreussen 
xi: reg f_rw f_prot $controls f_miss i.zupreussen
reg f_rw f_prot $controls f_miss if rhs==0
reg f_rw f_prot $controls f_miss if f_prot<20 | f_prot>80
reg f_over3km f_prot $controls


* Table 3: The Effect of Protestantism on Literacy: IV Results Based on Distance to Wittenberg

ivreg2 f_rw (f_prot = kmwittenberg) $controls f_miss, first
ivreg2 f_over3km (f_prot = kmwittenberg) $controls


* Table 4: Exogeneity of Distance-to-Wittenberg Instrument

reg reichsstadt kmwittenberg
reg hansestadt kmwittenberg
reg dnpop1500 kmwittenberg
preserve
use city.dta
reg pop1500 kmwittenberg
restore

reg uni1517 kmwittenberg
preserve
use unifound.dta
reg unifound kmwittenberg
restore

reg ncloisters1517_pkm2 kmwittenberg sh_al_in_tot
reg school1517 kmwittenberg if poland==0
preserve
use schoolfound.dta
reg est kmwittenberg
restore


* Table 5: Protestantism and Economic Outcomes in 19th-Century Prussia 

reg inctaxpc f_prot $controls
reg lnyteacher f_prot $controls
reg perc_secBnC f_prot $controls

ivreg inctaxpc (f_prot = kmwittenberg) $controls
ivreg lnyteacher (f_prot = kmwittenberg) $controls
ivreg perc_secBnC (f_prot = kmwittenberg) $controls

reg inctaxpc f_prot f_rw $controls f_miss
reg lnyteacher f_prot f_rw $controls f_miss
reg perc_secBnC f_prot f_rw $controls f_miss


* Table 6: Effect of Protestantism on Economic Outcomes after Adjusting for Literacy: Bounding Analysis

quietly: reg inctaxpc f_prot f_rw $controls f_miss
for num 1/7 \ num .6 .8 .9 1 1.1 1.2 1.4: gen tX = inctaxpc - Y * _b[f_rw] * f_rw
for num 1/7: ivreg tX (f_prot = kmwittenberg) $controls

quietly: reg lnyteacher f_prot f_rw $controls f_miss
for num 1/7 \ num .6 .8 .9 1 1.1 1.2 1.4: gen yX = lnyteacher - Y * _b[f_rw] * f_rw
for num 1/7: ivreg yX (f_prot = kmwittenberg) $controls

quietly: reg perc_secBnC f_prot f_rw $controls f_miss
for num 1/7 \ num .6 .8 .9 1 1.1 1.2 1.4: gen pX = perc_secBnC - Y * _b[f_rw] * f_rw
for num 1/7: ivreg pX (f_prot = kmwittenberg) $controls


* Table 7: Effect of Protestantism on Income after Adjusting for Literacy: Bounding Analysis

gen h=.
foreach X of numlist 4(1)7 {
  foreach Y of numlist 8(1)15 {
    replace h = lnyteacher - `X' * `Y' * f_rw/100
	ivreg h (f_prot = kmwittenberg) $controls
  }
}
drop h


* Table 8: Protestantism, Literacy, and Economic Outcome: A 3SLS Model

reg3 (inctaxpc f_rw $controls f_miss) (f_rw f_prot $controls f_miss) (f_prot kmwittenberg $controls f_miss)


log close


